@@ -1,10 +1,11 @@
 from ctypes import c_float
 
+from ..util import compat
 from .base import FormatColumn
 
 
 class FloatColumn(FormatColumn):
-    py_types = (float, int)
+    py_types = (float, ) + compat.integer_types
 
 
 class Float32(FloatColumn):
